# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class IntegrationConfiguration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationConfiguration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'int',
            'properties_schema_uri': 'str',
            'advanced_schema_uri': 'str',
            'properties': 'object',
            'advanced': 'object',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'properties_schema_uri': 'propertiesSchemaUri',
            'advanced_schema_uri': 'advancedSchemaUri',
            'properties': 'properties',
            'advanced': 'advanced',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._properties_schema_uri = None
        self._advanced_schema_uri = None
        self._properties = None
        self._advanced = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this IntegrationConfiguration.
        The globally unique identifier for the object.

        :return: The id of this IntegrationConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IntegrationConfiguration.
        The globally unique identifier for the object.

        :param id: The id of this IntegrationConfiguration.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this IntegrationConfiguration.


        :return: The name of this IntegrationConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IntegrationConfiguration.


        :param name: The name of this IntegrationConfiguration.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this IntegrationConfiguration.
        Version number required for updates.

        :return: The version of this IntegrationConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this IntegrationConfiguration.
        Version number required for updates.

        :param version: The version of this IntegrationConfiguration.
        :type: int
        """
        
        self._version = version

    @property
    def properties_schema_uri(self):
        """
        Gets the properties_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the configuration properties in the properties field.

        :return: The properties_schema_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._properties_schema_uri

    @properties_schema_uri.setter
    def properties_schema_uri(self, properties_schema_uri):
        """
        Sets the properties_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the configuration properties in the properties field.

        :param properties_schema_uri: The properties_schema_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._properties_schema_uri = properties_schema_uri

    @property
    def advanced_schema_uri(self):
        """
        Gets the advanced_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the advanced configuration

        :return: The advanced_schema_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._advanced_schema_uri

    @advanced_schema_uri.setter
    def advanced_schema_uri(self, advanced_schema_uri):
        """
        Sets the advanced_schema_uri of this IntegrationConfiguration.
        URI for the JSON Schema describing the advanced configuration

        :param advanced_schema_uri: The advanced_schema_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._advanced_schema_uri = advanced_schema_uri

    @property
    def properties(self):
        """
        Gets the properties of this IntegrationConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :return: The properties of this IntegrationConfiguration.
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this IntegrationConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :param properties: The properties of this IntegrationConfiguration.
        :type: object
        """
        
        self._properties = properties

    @property
    def advanced(self):
        """
        Gets the advanced of this IntegrationConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :return: The advanced of this IntegrationConfiguration.
        :rtype: object
        """
        return self._advanced

    @advanced.setter
    def advanced(self, advanced):
        """
        Sets the advanced of this IntegrationConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :param advanced: The advanced of this IntegrationConfiguration.
        :type: object
        """
        
        self._advanced = advanced

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IntegrationConfiguration.
        The URI for this object

        :return: The self_uri of this IntegrationConfiguration.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IntegrationConfiguration.
        The URI for this object

        :param self_uri: The self_uri of this IntegrationConfiguration.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

